# Documentation for watex

This directory contains the full manual and user guide as displayed at
http://https://watex.readthedocs.io/. 
See https://watex.readthedocs.io/en/latest/user_guide.htmlfor 
detailed information about the documentation. 